Coverage report

File | function | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/pydantic_typer/__init__.py | (no function) | 2 | 0 | 0 | 0 | 0 | 100%
src/pydantic_typer/main.py | _flatten_pydantic_model | 18 | 0 | 0 | 10 | 0 | 100%
src/pydantic_typer/main.py | enable_pydantic | 19 | 0 | 0 | 10 | 0 | 100%
src/pydantic_typer/main.py | enable_pydantic.wrapper | 14 | 0 | 0 | 8 | 1 | 95%
src/pydantic_typer/main.py | enable_pydantic_type_validation | 24 | 0 | 0 | 12 | 0 | 100%
src/pydantic_typer/main.py | enable_pydantic_type_validation.wrapper | 11 | 0 | 0 | 2 | 0 | 100%
src/pydantic_typer/main.py | Typer.command | 3 | 0 | 0 | 0 | 0 | 100%
src/pydantic_typer/main.py | Typer.command.decorator_override | 3 | 0 | 0 | 0 | 0 | 100%
src/pydantic_typer/main.py | run | 3 | 0 | 0 | 0 | 0 | 100%
src/pydantic_typer/main.py | (no function) | 21 | 0 | 0 | 2 | 0 | 100%
src/pydantic_typer/utils.py | deep_update | 7 | 0 | 0 | 6 | 0 | 100%
src/pydantic_typer/utils.py | _get_type_hints | 0 | 0 | 5 | 0 | 0 | 100%
src/pydantic_typer/utils.py | inspect_signature | 0 | 0 | 14 | 0 | 0 | 100%
src/pydantic_typer/utils.py | copy_type | 1 | 0 | 0 | 2 | 0 | 100%
src/pydantic_typer/utils.py | (no function) | 8 | 0 | 2 | 0 | 0 | 100%
unit_tests/__init__.py | (no function) | 0 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_001_basic.py | test_help | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_001_basic.py | test_parse_pydantic_model | 3 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_001_basic.py | test_script | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_001_basic.py | (no function) | 11 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_002_nested_models.py | test_help | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_002_nested_models.py | test_parse_pydantic_model | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_002_nested_models.py | test_script | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_002_nested_models.py | (no function) | 11 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_003_annotated_argument.py | test_help | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_003_annotated_argument.py | test_parse_pydantic_model | 3 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_003_annotated_argument.py | test_wrong_order | 3 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_003_annotated_argument.py | test_script | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_003_annotated_argument.py | (no function) | 12 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_004_argument_override.py | test_help | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_004_argument_override.py | test_parse_pydantic_model | 3 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_004_argument_override.py | test_script | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_004_argument_override.py | (no function) | 11 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_005_multi_commands.py | test_help | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_005_multi_commands.py | test_all_commands | 4 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_005_multi_commands.py | test_script | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_005_multi_commands.py | (no function) | 9 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_006_pydantic_types.py | test_help | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_006_pydantic_types.py | test_valid_input | 3 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_006_pydantic_types.py | test_invalid_url | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_006_pydantic_types.py | test_script | 2 | 0 | 0 | 0 | 0 | 100%
unit_tests/test_006_pydantic_types.py | (no function) | 12 | 0 | 0 | 0 | 0 | 100%
Total |  | 247 | 0 | 21 | 52 | 1 | 99%

No items found using the specified filter.